@@ -17,7 +17,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(finddeps);
 
-$VERSION = '2.41';
+$VERSION = '2.42';
 
 use constant DEFAULT02PACKAGES => 'http://www.cpan.org/modules/02packages.details.txt.gz';
 use constant MAXINT => ~0;
@@ -351,7 +351,7 @@ sub _finddeps_uncached {
                 seen    => $seen,
                 version => $reqs{$_}
             );
-        } keys %reqs) : ()
+        } sort keys %reqs) : ()
     ];
 }
 
